@@ -5,4 +5,4 @@ def test_creation():
     folder = 'tests/data/catalog/'
     catalog = starepandas.folder2catalog(path=folder, granule_extension='hdf', add_sf=False)
     print(catalog)
-    assert catalog.size == 15
+    assert catalog.index.size == 3
